@@ -112,14 +112,17 @@ def flatten_curve(orig_a,
         order_restored[j] = i
     rank_order_match = np.all(np.argsort(orig_a) == np.argsort(order_restored))
     if rank_order_match is False:
-        print("ERROR! Rank order did not match!")
+        notif_msg = "ERROR! Rank order did not match!"
+        print(notif_msg)
+        logging.error(notif_msg)
         return
     if plot:
         sns.kdeplot(orig_a, color='b')
         sns.kdeplot(order_restored, color='g')
         plt.show()
 
-    print("Rank order matched!")
+    logging.info("Rank order matched!")
+
     if return_bin_info:
         return order_restored, {'lower': lower, 'upper': upper, 'bins': num_bins, 'boundaries': boundaries,
                                 'scalers': min_max_scalers, 'deltas': deltas}
